Module adapter

Module adapter 

Modules

mcp
openclaw

Traits

Adapter
An adapter detects a specific agent framework and loads its artifacts into the unified IR.

Functions

all_adapters
All registered adapters.
auto_detect_and_load
Auto-detect all matching frameworks and load scan targets from each.