Adapter

Trait Adapter 

pub trait Adapter: Send + Sync {
    // Required methods
    fn framework(&self) -> Framework;
    fn detect(&self, root: &Path) -> bool;
    fn load(&self, root: &Path) -> Result<Vec<ScanTarget>>;
}
An adapter detects a specific agent framework and loads its artifacts into the unified IR.

Required Methods

fn framework(&self) -> Framework

The framework this adapter handles.

fn detect(&self, root: &Path) -> bool

Check if this adapter can handle the given directory.

fn load(&self, root: &Path) -> Result<Vec<ScanTarget>>

Load artifacts from the directory into scan targets.

Implementors