Module cross_file

Module cross_file 

Cross-file sanitizer-aware validation tracking.

Runs after parsing, before detection. When a function is only ever called with sanitized arguments, downgrades its parameters’ from tainted to . This eliminates false positives from internal helper functions that receive already-validated input from their callers.

Structs

CrossFileResult
Result of cross-file sanitization analysis.

Functions

apply_cross_file_sanitization
Perform cross-file sanitizer-aware analysis on parsed files.
sanitizer_allows_sink
Whether sanitizer neutralizes taint for sink.