Modules
Structs
- Applied
Fix - Summary of a fix applied to a single line or AST node.
- File
Patch - A patch containing original and modified file contents along with applied fixes.
- FixEngine
- Core autofix orchestrator.
- FixOutput
- Helper struct returned by individual fixer modules.
Functions
- generate_
unified_ diff - Simple line-based unified diff generator.