pub fn render(findings: &[Finding], verdict: &PolicyVerdict) -> StringExpand description
Render findings as colored console output, grouped by severity then file path.
pub fn render(findings: &[Finding], verdict: &PolicyVerdict) -> StringRender findings as colored console output, grouped by severity then file path.