pub fn render(
findings: &[Finding],
verdict: &PolicyVerdict,
format: OutputFormat,
target_name: &str,
scan_root: &Path,
) -> Result<String>Expand description
Render findings into the specified format.
scan_root is used to compute stable, portable fingerprints for each
finding (relative to the scan directory so they survive path changes).