Modules
- autogen
- crewai
- cursor_
rules - Cursor Rules adapter.
- gpt_
actions - GPT Actions adapter.
- hermes
- Hermes Agent adapter.
- langchain
- llama_
index - mcp
- openclaw
- semantic_
kernel - vercel_
ai
Traits
- Adapter
- An adapter detects a specific agent framework and loads its artifacts into the unified IR.
Functions
- auto_
detect_ and_ load - Auto-detect all matching frameworks and load scan targets from each.
- auto_
detect_ and_ load_ with_ filter