Interprocedural call-graph and cross-function taint propagation engine (milestone v1.0.0).
Analyzes cross-function and cross-method control/data flow across Python and TypeScript agent extensions. Connects tool input parameters that are passed through intermediate helper functions, utility wrappers, and class methods to downstream execution sinks.
Re-exports
pub use propagate::propagate_interprocedural_taint;pub use types::CallGraph;pub use types::CallSite;pub use types::FunctionNode;