Interprocedural call-graph and cross-function taint propagation engine (milestone v1.0.0).
Analyzes cross-function and cross-method control/data flow across Python and TypeScript agent extensions. Connects tool input parameters that are passed through intermediate helper functions, utility wrappers, and class methods to downstream execution sinks.
Structs
- Call
Graph - Interprocedural Call Graph.
- Call
Site - A call-site invoking a function.
- Function
Node - A representation of a function definition in the project.
Functions
- propagate_
interprocedural_ taint - Propagates taint across call-graph edges and constructs multi-hop
TaintPathinstances.